[![Build Status](https://travis-ci.org/fish2000/django-docfield-couchdb.png?branch=master)](https://travis-ci.org/fish2000/django-docfield-couchdb)

django-docfield-couchdb
=======================

Django fields for representing CouchDB docs other idioms.
---------------------------------------------------------

Django fields and other add-ons that represent key CouchDB data structures:

* Docs, which can authoratively reside in either Couch or your Django RDBMS
* Arbitrary JSON subtrees
* CouchDB _id and _rev identifiers
* NEW in 1.1: an error-free setup.py install experience!

And MORE!!! Coming soon of course.

[![Bitdeli Badge](https://d2weczhvl823v0.cloudfront.net/fish2000/django-docfield-couchdb/trend.png)](https://bitdeli.com/free "Bitdeli Badge")
